"use client"

import { useState, useEffect } from "react"
import { useRouter } from "next/navigation"
import { Button } from "@/components/ui/button"
import { Card, CardContent, CardDescription, CardHeader, CardTitle } from "@/components/ui/card"
import { Badge } from "@/components/ui/badge"
import { Tabs, TabsContent, TabsList, TabsTrigger } from "@/components/ui/tabs"
import { Input } from "@/components/ui/input"
import { Label } from "@/components/ui/label"
import { Checkbox } from "@/components/ui/checkbox"
import { Select, SelectContent, SelectItem, SelectTrigger, SelectValue } from "@/components/ui/select"
import {
  FileText,
  Users,
  DollarSign,
  TrendingUp,
  Search,
  MoreHorizontal,
  CheckCircle,
  XCircle,
  Clock,
  AlertTriangle,
  Settings,
  LogOut,
  Shield,
  Save,
  GraduationCap,
  Eye,
  Download,
  Mail,
  Star,
  MessageSquare,
  CreditCard,
  Ban,
  UserCheck,
  UserX,
  RefreshCw,
  BarChart3,
} from "lucide-react"
import { getAuthenticatedUser, isAdmin, logout } from "@/lib/auth"
import { useOrders, useWriters, useClients, useStats, useDataActions } from "@/hooks/use-data-store"

export default function AdminDashboard() {
  const router = useRouter()
  const [user, setUser] = useState<any>(null)
  const [isLoading, setIsLoading] = useState(true)
  const [activeTab, setActiveTab] = useState("overview")

  // Data from store
  const orders = useOrders()
  const writers = useWriters()
  const clients = useClients()
  const stats = useStats()
  const { updateOrder, updateWriter, assignWriterToOrder, updateWriterApplication } = useDataActions()

  // Filter states
  const [orderFilter, setOrderFilter] = useState("")
  const [statusFilter, setStatusFilter] = useState("all")

  // Settings state
  const [settings, setSettings] = useState({
    pricing: {
      basePrice: 10,
      highSchoolMultiplier: 1.0,
      undergraduateMultiplier: 1.3,
      mastersMultiplier: 1.6,
      phdMultiplier: 2.2,
      urgencyMultipliers: {
        oneDay: 2.5,
        threeDays: 1.8,
        oneWeek: 1.4,
        twoWeeks: 1.2,
      },
    },
    platform: {
      commissionRate: 15,
      minimumWithdrawal: 50,
      paymentMethods: ["PayPal", "Bank Transfer", "Payoneer"],
      autoApproveWriters: false,
      requirePhoneVerification: true,
      allowGuestOrders: false,
    },
    general: {
      siteName: "ProEssayWorks",
      supportEmail: "support@proessayworks.com",
      maxFileSize: 10,
      allowedFileTypes: [".pdf", ".doc", ".docx", ".txt"],
      maintenanceMode: false,
      registrationOpen: true,
    },
    notifications: {
      emailNotifications: true,
      smsNotifications: false,
      orderUpdates: true,
      paymentAlerts: true,
      systemAlerts: true,
    },
  })

  useEffect(() => {
    const authenticatedUser = getAuthenticatedUser()

    if (!authenticatedUser || !isAdmin()) {
      router.push("/auth/login")
      return
    }

    setUser(authenticatedUser)
    setIsLoading(false)
  }, [router])

  const handleLogout = () => {
    logout()
  }

  const handleSaveSettings = () => {
    // In a real app, this would save to a database
    alert("Settings saved successfully!")
  }

  const getStatusBadge = (status: string) => {
    switch (status) {
      case "pending":
        return (
          <Badge variant="secondary" className="status-pending">
            <Clock className="w-3 h-3 mr-1" />
            Pending
          </Badge>
        )
      case "payment_pending":
        return (
          <Badge variant="outline" className="border-yellow-500 text-yellow-700">
            <CreditCard className="w-3 h-3 mr-1" />
            Payment Pending
          </Badge>
        )
      case "paid":
        return (
          <Badge variant="default">
            <CheckCircle className="w-3 h-3 mr-1" />
            Paid
          </Badge>
        )
      case "assigned":
        return (
          <Badge variant="default">
            <UserCheck className="w-3 h-3 mr-1" />
            Assigned
          </Badge>
        )
      case "in_progress":
        return (
          <Badge variant="default" className="status-progress">
            <AlertTriangle className="w-3 h-3 mr-1" />
            In Progress
          </Badge>
        )
      case "completed":
        return (
          <Badge variant="secondary" className="status-completed">
            <CheckCircle className="w-3 h-3 mr-1" />
            Completed
          </Badge>
        )
      case "disputed":
        return (
          <Badge variant="destructive" className="status-error">
            <XCircle className="w-3 h-3 mr-1" />
            Disputed
          </Badge>
        )
      case "revision":
        return (
          <Badge variant="outline" className="status-warning">
            <RefreshCw className="w-3 h-3 mr-1" />
            Revision
          </Badge>
        )
      case "approved":
        return (
          <Badge variant="secondary" className="status-completed">
            <CheckCircle className="w-3 h-3 mr-1" />
            Approved
          </Badge>
        )
      case "rejected":
        return (
          <Badge variant="destructive" className="status-error">
            <XCircle className="w-3 h-3 mr-1" />
            Rejected
          </Badge>
        )
      case "active":
        return (
          <Badge variant="secondary" className="status-completed">
            <CheckCircle className="w-3 h-3 mr-1" />
            Active
          </Badge>
        )
      case "vip":
        return (
          <Badge variant="default" className="bg-gold text-white">
            <Star className="w-3 h-3 mr-1" />
            VIP
          </Badge>
        )
      default:
        return <Badge variant="outline">{status}</Badge>
    }
  }

  const getPriorityBadge = (priority: string) => {
    switch (priority) {
      case "high":
        return <Badge variant="destructive">High</Badge>
      case "normal":
        return <Badge variant="outline">Normal</Badge>
      case "low":
        return <Badge variant="secondary">Low</Badge>
      default:
        return <Badge variant="outline">{priority}</Badge>
    }
  }

  const updateOrderStatus = (orderId: string, newStatus: string) => {
    updateOrder(orderId, { status: newStatus as any })
  }

  const approveWriter = (writerId: string) => {
    updateWriter(writerId, { status: "approved" })
  }

  const rejectWriter = (writerId: string) => {
    updateWriter(writerId, { status: "rejected" })
  }

  const handleAssignWriter = (orderId: string, applicationId: string, writerId: string) => {
    assignWriterToOrder(orderId, writerId, applicationId)
    alert("Writer assigned successfully!")
  }

  const filteredOrders = orders.filter((order) => {
    const matchesSearch =
      order.title.toLowerCase().includes(orderFilter.toLowerCase()) ||
      order.client.toLowerCase().includes(orderFilter.toLowerCase()) ||
      order.id.toLowerCase().includes(orderFilter.toLowerCase())
    const matchesStatus = statusFilter === "all" || order.status === statusFilter
    return matchesSearch && matchesStatus
  })

  if (isLoading) {
    return (
      <div className="min-h-screen bg-slate-50 flex items-center justify-center">
        <div className="text-center">
          <div className="animate-spin rounded-full h-12 w-12 border-b-2 border-slate-800 mx-auto mb-4"></div>
          <p>Loading admin dashboard...</p>
        </div>
      </div>
    )
  }

  return (
    <div className="min-h-screen dashboard-academic">
      {/* Header */}
      <header className="dashboard-header-academic">
        <div className="max-w-7xl mx-auto container-padding">
          <div className="flex justify-between items-center py-4">
            <div className="flex items-center">
              <GraduationCap className="h-8 w-8 text-gray-700" />
              <span className="ml-2 text-xl font-bold text-navy-900">ProEssayWorks Admin</span>
            </div>
            <div className="flex items-center space-x-4">
              <div className="flex items-center space-x-2 px-3 py-1 bg-blue-50 rounded-lg">
                <Shield className="h-4 w-4 text-blue-600" />
                <span className="text-sm font-medium text-blue-800">Admin: {user?.name}</span>
              </div>
              <Button variant="ghost" size="sm" onClick={() => setActiveTab("settings")}>
                <Settings className="h-4 w-4 mr-2" />
                Settings
              </Button>
              <Button variant="ghost" size="sm" onClick={handleLogout}>
                <LogOut className="h-4 w-4 mr-2" />
                Logout
              </Button>
            </div>
          </div>
        </div>
      </header>

      <div className="max-w-7xl mx-auto container-padding py-8">
        {/* Welcome Section */}
        <div className="mb-8">
          <h1 className="heading-secondary-academic text-navy-900 mb-2">Admin Dashboard</h1>
          <p className="body-regular text-gray-700">Monitor and manage the ProEssayWorks platform</p>
        </div>

        {/* Quick Stats Cards */}
        <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-4 gap-6 mb-8">
          <Card className="stat-card">
            <CardHeader className="flex flex-row items-center justify-between space-y-0 pb-2">
              <CardTitle className="text-sm font-medium text-gray-600">Total Revenue</CardTitle>
              <DollarSign className="h-4 w-4 text-green-600" />
            </CardHeader>
            <CardContent>
              <div className="text-2xl font-bold text-navy-900">${stats.totalRevenue}</div>
              <p className="text-xs text-green-600">+12% from last month</p>
            </CardContent>
          </Card>
          <Card className="stat-card">
            <CardHeader className="flex flex-row items-center justify-between space-y-0 pb-2">
              <CardTitle className="text-sm font-medium text-gray-600">Active Orders</CardTitle>
              <FileText className="h-4 w-4 text-blue-600" />
            </CardHeader>
            <CardContent>
              <div className="text-2xl font-bold text-navy-900">{stats.activeOrders}</div>
              <p className="text-xs text-blue-600">{orders.filter((o) => o.status === "pending").length} pending</p>
            </CardContent>
          </Card>
          <Card className="stat-card">
            <CardHeader className="flex flex-row items-center justify-between space-y-0 pb-2">
              <CardTitle className="text-sm font-medium text-gray-600">Active Writers</CardTitle>
              <Users className="h-4 w-4 text-purple-600" />
            </CardHeader>
            <CardContent>
              <div className="text-2xl font-bold text-navy-900">
                {writers.filter((w) => w.status === "approved").length}
              </div>
              <p className="text-xs text-purple-600">
                {writers.filter((w) => w.status === "pending").length} pending approval
              </p>
            </CardContent>
          </Card>
          <Card className="stat-card">
            <CardHeader className="flex flex-row items-center justify-between space-y-0 pb-2">
              <CardTitle className="text-sm font-medium text-gray-600">Total Clients</CardTitle>
              <TrendingUp className="h-4 w-4 text-orange-600" />
            </CardHeader>
            <CardContent>
              <div className="text-2xl font-bold text-navy-900">{clients.length}</div>
              <p className="text-xs text-orange-600">+8% growth</p>
            </CardContent>
          </Card>
        </div>

        {/* Main Content */}
        <Tabs value={activeTab} onValueChange={setActiveTab} className="space-y-6">
          <TabsList className="grid w-full grid-cols-6">
            <TabsTrigger value="overview">Overview</TabsTrigger>
            <TabsTrigger value="orders">Orders</TabsTrigger>
            <TabsTrigger value="writers">Writers</TabsTrigger>
            <TabsTrigger value="clients">Clients</TabsTrigger>
            <TabsTrigger value="analytics">Analytics</TabsTrigger>
            <TabsTrigger value="settings">Settings</TabsTrigger>
          </TabsList>

          <TabsContent value="overview" className="space-y-6">
            {/* Overview Dashboard */}
            <div className="grid grid-cols-1 lg:grid-cols-2 gap-6">
              {/* Recent Orders */}
              <Card className="card-modern">
                <CardHeader>
                  <CardTitle className="heading-tertiary-academic">Recent Orders</CardTitle>
                </CardHeader>
                <CardContent>
                  <div className="space-y-4">
                    {orders.slice(0, 5).map((order) => (
                      <div key={order.id} className="flex items-center justify-between p-3 border rounded-lg">
                        <div>
                          <p className="font-medium">{order.title}</p>
                          <p className="text-sm text-gray-600">{order.clientName}</p>
                        </div>
                        <div className="text-right">
                          {getStatusBadge(order.status)}
                          <p className="text-sm text-gray-600 mt-1">${order.amount}</p>
                        </div>
                      </div>
                    ))}
                  </div>
                </CardContent>
              </Card>

              {/* Pending Actions */}
              <Card className="card-modern">
                <CardHeader>
                  <CardTitle className="heading-tertiary-academic">Pending Actions</CardTitle>
                </CardHeader>
                <CardContent>
                  <div className="space-y-4">
                    <div className="flex items-center justify-between p-3 border rounded-lg bg-yellow-50">
                      <div className="flex items-center">
                        <AlertTriangle className="h-5 w-5 text-yellow-600 mr-3" />
                        <div>
                          <p className="font-medium">Writer Applications</p>
                          <p className="text-sm text-gray-600">
                            {writers.filter((w) => w.status === "pending").length} pending review
                          </p>
                        </div>
                      </div>
                      <Button size="sm" onClick={() => setActiveTab("writers")}>
                        Review
                      </Button>
                    </div>

                    <div className="flex items-center justify-between p-3 border rounded-lg bg-blue-50">
                      <div className="flex items-center">
                        <FileText className="h-5 w-5 text-blue-600 mr-3" />
                        <div>
                          <p className="font-medium">Order Applications</p>
                          <p className="text-sm text-gray-600">
                            {orders.reduce(
                              (sum, o) => sum + o.writerApplications.filter((app) => app.status === "pending").length,
                              0,
                            )}{" "}
                            pending review
                          </p>
                        </div>
                      </div>
                      <Button size="sm" onClick={() => setActiveTab("orders")}>
                        Review
                      </Button>
                    </div>

                    <div className="flex items-center justify-between p-3 border rounded-lg bg-red-50">
                      <div className="flex items-center">
                        <XCircle className="h-5 w-5 text-red-600 mr-3" />
                        <div>
                          <p className="font-medium">Disputed Orders</p>
                          <p className="text-sm text-gray-600">
                            {orders.filter((o) => o.status === "disputed").length} require attention
                          </p>
                        </div>
                      </div>
                      <Button size="sm" onClick={() => setActiveTab("orders")}>
                        Resolve
                      </Button>
                    </div>
                  </div>
                </CardContent>
              </Card>
            </div>
          </TabsContent>

          <TabsContent value="orders" className="space-y-6">
            <Card className="card-modern">
              <CardHeader>
                <div className="flex justify-between items-center">
                  <div>
                    <CardTitle className="heading-tertiary-academic">Order Management</CardTitle>
                    <CardDescription className="body-regular text-gray-700">
                      Monitor and manage all orders on the platform
                    </CardDescription>
                  </div>
                  <div className="flex space-x-2">
                    <div className="relative">
                      <Search className="absolute left-2 top-2.5 h-4 w-4 text-gray-400" />
                      <Input
                        placeholder="Search orders..."
                        className="pl-8 form-input"
                        value={orderFilter}
                        onChange={(e) => setOrderFilter(e.target.value)}
                      />
                    </div>
                    <Select value={statusFilter} onValueChange={setStatusFilter}>
                      <SelectTrigger className="w-40">
                        <SelectValue placeholder="Filter by status" />
                      </SelectTrigger>
                      <SelectContent>
                        <SelectItem value="all">All Status</SelectItem>
                        <SelectItem value="pending">Pending</SelectItem>
                        <SelectItem value="paid">Paid</SelectItem>
                        <SelectItem value="assigned">Assigned</SelectItem>
                        <SelectItem value="in_progress">In Progress</SelectItem>
                        <SelectItem value="completed">Completed</SelectItem>
                        <SelectItem value="disputed">Disputed</SelectItem>
                        <SelectItem value="revision">Revision</SelectItem>
                      </SelectContent>
                    </Select>
                    <Button variant="outline" className="btn-outline">
                      <Download className="h-4 w-4 mr-2" />
                      Export
                    </Button>
                  </div>
                </div>
              </CardHeader>
              <CardContent>
                <div className="space-y-4">
                  {filteredOrders.map((order) => (
                    <div
                      key={order.id}
                      className="border border-slate-200 rounded-lg p-4 hover:bg-slate-50 transition-colors"
                    >
                      <div className="flex justify-between items-start mb-3">
                        <div className="flex-1">
                          <div className="flex items-center space-x-3 mb-2">
                            <h3 className="font-semibold">{order.title}</h3>
                            {getPriorityBadge(order.priority)}
                            {getStatusBadge(order.status)}
                          </div>
                          <div className="grid grid-cols-2 md:grid-cols-4 gap-4 text-sm text-gray-600">
                            <div>
                              <span className="font-medium">Order ID:</span> {order.id}
                            </div>
                            <div>
                              <span className="font-medium">Client:</span> {order.clientName}
                            </div>
                            <div>
                              <span className="font-medium">Writer:</span> {order.writerName || "Unassigned"}
                            </div>
                            <div>
                              <span className="font-medium">Amount:</span> ${order.amount}
                            </div>
                            <div>
                              <span className="font-medium">Pages:</span> {order.pages}
                            </div>
                            <div>
                              <span className="font-medium">Level:</span> {order.academicLevel}
                            </div>
                            <div>
                              <span className="font-medium">Deadline:</span>{" "}
                              {new Date(order.deadline).toLocaleDateString()}
                            </div>
                            <div>
                              <span className="font-medium">Progress:</span> {order.progress}%
                            </div>
                          </div>

                          {/* Writer Applications */}
                          {order.writerApplications.length > 0 && (
                            <div className="mt-4">
                              <h4 className="font-medium text-sm mb-2">
                                Writer Applications ({order.writerApplications.length})
                              </h4>
                              <div className="space-y-2">
                                {order.writerApplications.map((app) => (
                                  <div
                                    key={app.id}
                                    className="flex items-center justify-between p-2 bg-gray-50 rounded"
                                  >
                                    <div className="flex-1">
                                      <p className="font-medium text-sm">{app.writerName}</p>
                                      <p className="text-xs text-gray-600">
                                        Bid: ${app.bidAmount} • {app.experience}
                                      </p>
                                      <p className="text-xs text-gray-500 mt-1">{app.proposal.substring(0, 100)}...</p>
                                    </div>
                                    <div className="flex items-center space-x-2">
                                      {getStatusBadge(app.status)}
                                      {app.status === "pending" && (
                                        <>
                                          <Button
                                            size="sm"
                                            className="btn-primary"
                                            onClick={() => handleAssignWriter(order.id, app.id, app.writerId)}
                                          >
                                            Assign
                                          </Button>
                                          <Button
                                            size="sm"
                                            variant="destructive"
                                            onClick={() => updateWriterApplication(app.id, { status: "rejected" })}
                                          >
                                            Reject
                                          </Button>
                                        </>
                                      )}
                                    </div>
                                  </div>
                                ))}
                              </div>
                            </div>
                          )}

                          {order.status === "in_progress" && (
                            <div className="mt-3">
                              <div className="w-full bg-gray-200 rounded-full h-2">
                                <div
                                  className="bg-blue-600 h-2 rounded-full transition-all duration-300"
                                  style={{ width: `${order.progress}%` }}
                                ></div>
                              </div>
                            </div>
                          )}
                        </div>
                        <div className="flex items-center space-x-2 ml-4">
                          <Select onValueChange={(value) => updateOrderStatus(order.id, value)}>
                            <SelectTrigger className="w-32">
                              <SelectValue placeholder="Update Status" />
                            </SelectTrigger>
                            <SelectContent>
                              <SelectItem value="pending">Pending</SelectItem>
                              <SelectItem value="paid">Paid</SelectItem>
                              <SelectItem value="assigned">Assigned</SelectItem>
                              <SelectItem value="in_progress">In Progress</SelectItem>
                              <SelectItem value="completed">Completed</SelectItem>
                              <SelectItem value="revision">Revision</SelectItem>
                              <SelectItem value="disputed">Disputed</SelectItem>
                            </SelectContent>
                          </Select>
                          <Button variant="ghost" size="sm">
                            <Eye className="h-4 w-4" />
                          </Button>
                          <Button variant="ghost" size="sm">
                            <MessageSquare className="h-4 w-4" />
                          </Button>
                          <Button variant="ghost" size="sm">
                            <MoreHorizontal className="h-4 w-4" />
                          </Button>
                        </div>
                      </div>
                    </div>
                  ))}
                </div>
              </CardContent>
            </Card>
          </TabsContent>

          <TabsContent value="writers" className="space-y-6">
            <Card className="card-modern">
              <CardHeader>
                <CardTitle className="heading-tertiary-academic">Writer Management</CardTitle>
                <CardDescription className="body-regular text-gray-700">
                  Review applications and manage writer accounts
                </CardDescription>
              </CardHeader>
              <CardContent>
                <div className="space-y-6">
                  {writers.map((writer) => (
                    <div key={writer.id} className="border border-slate-200 rounded-lg p-6">
                      <div className="flex justify-between items-start mb-4">
                        <div className="flex-1">
                          <div className="flex items-center space-x-3 mb-2">
                            <h3 className="text-lg font-semibold">{writer.name}</h3>
                            {getStatusBadge(writer.status)}
                            {writer.rating && (
                              <div className="flex items-center">
                                <Star className="h-4 w-4 text-yellow-500 mr-1" />
                                <span className="text-sm">{writer.rating}</span>
                              </div>
                            )}
                          </div>
                          <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-4 text-sm">
                            <div>
                              <span className="font-medium text-gray-700">Email:</span>
                              <p>{writer.email}</p>
                            </div>
                            <div>
                              <span className="font-medium text-gray-700">Phone:</span>
                              <p>{writer.phone}</p>
                            </div>
                            <div>
                              <span className="font-medium text-gray-700">Education:</span>
                              <p>{writer.education}</p>
                            </div>
                            <div>
                              <span className="font-medium text-gray-700">Experience:</span>
                              <p>{writer.experience}</p>
                            </div>
                            <div>
                              <span className="font-medium text-gray-700">Applied:</span>
                              <p>{new Date(writer.appliedDate).toLocaleDateString()}</p>
                            </div>
                            <div>
                              <span className="font-medium text-gray-700">Completed Orders:</span>
                              <p>{writer.completedOrders}</p>
                            </div>
                          </div>
                          <div className="mt-3">
                            <span className="font-medium text-gray-700">Specializations:</span>
                            <div className="flex flex-wrap gap-2 mt-1">
                              {writer.specializations.map((spec, index) => (
                                <Badge key={index} variant="outline">
                                  {spec}
                                </Badge>
                              ))}
                            </div>
                          </div>
                          <div className="mt-3">
                            <span className="font-medium text-gray-700">Bio:</span>
                            <p className="text-gray-600 mt-1">{writer.bio}</p>
                          </div>
                        </div>
                        <div className="flex flex-col space-y-2 ml-6">
                          {writer.status === "pending" && (
                            <>
                              <Button size="sm" className="btn-primary" onClick={() => approveWriter(writer.id)}>
                                <UserCheck className="h-4 w-4 mr-2" />
                                Approve
                              </Button>
                              <Button size="sm" variant="destructive" onClick={() => rejectWriter(writer.id)}>
                                <UserX className="h-4 w-4 mr-2" />
                                Reject
                              </Button>
                            </>
                          )}
                          <Button size="sm" variant="outline">
                            <Mail className="h-4 w-4 mr-2" />
                            Contact
                          </Button>
                        </div>
                      </div>
                    </div>
                  ))}
                </div>
              </CardContent>
            </Card>
          </TabsContent>

          <TabsContent value="clients" className="space-y-6">
            <Card className="card-modern">
              <CardHeader>
                <CardTitle className="heading-tertiary-academic">Client Management</CardTitle>
                <CardDescription className="body-regular text-gray-700">
                  Monitor client accounts and activity
                </CardDescription>
              </CardHeader>
              <CardContent>
                <div className="space-y-4">
                  {clients.map((client) => (
                    <div
                      key={client.id}
                      className="border border-slate-200 rounded-lg p-4 hover:bg-slate-50 transition-colors"
                    >
                      <div className="flex justify-between items-start">
                        <div className="flex-1">
                          <div className="flex items-center space-x-3 mb-2">
                            <h3 className="font-semibold">{client.name}</h3>
                            {getStatusBadge(client.status)}
                            <div className="flex items-center">
                              <Star className="h-4 w-4 text-yellow-500 mr-1" />
                              <span className="text-sm">{client.rating}</span>
                            </div>
                          </div>
                          <div className="grid grid-cols-2 md:grid-cols-4 gap-4 text-sm text-gray-600">
                            <div>
                              <span className="font-medium">Email:</span> {client.email}
                            </div>
                            <div>
                              <span className="font-medium">Institution:</span> {client.institution}
                            </div>
                            <div>
                              <span className="font-medium">Total Orders:</span> {client.totalOrders}
                            </div>
                            <div>
                              <span className="font-medium">Total Spent:</span> ${client.totalSpent}
                            </div>
                            <div>
                              <span className="font-medium">Join Date:</span>{" "}
                              {new Date(client.joinDate).toLocaleDateString()}
                            </div>
                            <div>
                              <span className="font-medium">Last Order:</span>{" "}
                              {new Date(client.lastOrder).toLocaleDateString()}
                            </div>
                          </div>
                        </div>
                        <div className="flex items-center space-x-2 ml-4">
                          <Button variant="ghost" size="sm">
                            <Eye className="h-4 w-4" />
                          </Button>
                          <Button variant="ghost" size="sm">
                            <Mail className="h-4 w-4" />
                          </Button>
                          <Button variant="ghost" size="sm">
                            <Ban className="h-4 w-4" />
                          </Button>
                        </div>
                      </div>
                    </div>
                  ))}
                </div>
              </CardContent>
            </Card>
          </TabsContent>

          <TabsContent value="analytics" className="space-y-6">
            <div className="grid grid-cols-1 lg:grid-cols-2 gap-6">
              {/* Revenue Chart */}
              <Card className="card-modern">
                <CardHeader>
                  <CardTitle className="heading-tertiary-academic">Platform Analytics</CardTitle>
                </CardHeader>
                <CardContent>
                  <div className="text-center py-8">
                    <BarChart3 className="h-16 w-16 text-gray-300 mx-auto mb-4" />
                    <p className="text-gray-500">Analytics charts coming soon...</p>
                    <div className="mt-4 grid grid-cols-2 gap-4 text-sm">
                      <div className="text-center">
                        <p className="font-semibold text-2xl text-green-600">${stats.totalRevenue}</p>
                        <p className="text-gray-600">Total Revenue</p>
                      </div>
                      <div className="text-center">
                        <p className="font-semibold text-2xl text-blue-600">{stats.completedOrders}</p>
                        <p className="text-gray-600">Completed Orders</p>
                      </div>
                    </div>
                  </div>
                </CardContent>
              </Card>

              {/* Performance Metrics */}
              <Card className="card-modern">
                <CardHeader>
                  <CardTitle className="heading-tertiary-academic">Performance Metrics</CardTitle>
                </CardHeader>
                <CardContent>
                  <div className="space-y-4">
                    <div className="flex justify-between items-center">
                      <span>Order Completion Rate</span>
                      <span className="font-semibold">85%</span>
                    </div>
                    <div className="w-full bg-gray-200 rounded-full h-2">
                      <div className="bg-green-600 h-2 rounded-full" style={{ width: "85%" }}></div>
                    </div>

                    <div className="flex justify-between items-center">
                      <span>Average Rating</span>
                      <span className="font-semibold">4.7/5</span>
                    </div>
                    <div className="w-full bg-gray-200 rounded-full h-2">
                      <div className="bg-yellow-500 h-2 rounded-full" style={{ width: "94%" }}></div>
                    </div>

                    <div className="flex justify-between items-center">
                      <span>Writer Approval Rate</span>
                      <span className="font-semibold">65%</span>
                    </div>
                    <div className="w-full bg-gray-200 rounded-full h-2">
                      <div className="bg-blue-600 h-2 rounded-full" style={{ width: "65%" }}></div>
                    </div>
                  </div>
                </CardContent>
              </Card>
            </div>
          </TabsContent>

          <TabsContent value="settings" className="space-y-6">
            {/* Pricing Settings */}
            <div className="settings-academic">
              <div className="settings-header-academic">
                <h3 className="heading-tertiary-academic">Pricing Configuration</h3>
                <p className="body-regular text-gray-700">
                  Set base prices and multipliers for different academic levels and urgency
                </p>
              </div>
              <div className="settings-grid-academic">
                <div>
                  <Label htmlFor="basePrice" className="form-label-academic">
                    Base Price per Page ($)
                  </Label>
                  <Input
                    id="basePrice"
                    type="number"
                    value={settings.pricing.basePrice}
                    onChange={(e) =>
                      setSettings({
                        ...settings,
                        pricing: { ...settings.pricing, basePrice: Number(e.target.value) },
                      })
                    }
                    className="form-input-academic"
                  />
                </div>
                <div>
                  <Label htmlFor="commissionRate" className="form-label-academic">
                    Platform Commission (%)
                  </Label>
                  <Input
                    id="commissionRate"
                    type="number"
                    value={settings.platform.commissionRate}
                    onChange={(e) =>
                      setSettings({
                        ...settings,
                        platform: { ...settings.platform, commissionRate: Number(e.target.value) },
                      })
                    }
                    className="form-input-academic"
                  />
                </div>
              </div>

              <div className="mt-6">
                <h4 className="text-lg font-semibold mb-4 text-navy-900">Academic Level Multipliers</h4>
                <div className="settings-grid-academic">
                  <div>
                    <Label htmlFor="highSchool" className="form-label-academic">
                      High School
                    </Label>
                    <Input
                      id="highSchool"
                      type="number"
                      step="0.1"
                      value={settings.pricing.highSchoolMultiplier}
                      onChange={(e) =>
                        setSettings({
                          ...settings,
                          pricing: { ...settings.pricing, highSchoolMultiplier: Number(e.target.value) },
                        })
                      }
                      className="form-input-academic"
                    />
                  </div>
                  <div>
                    <Label htmlFor="undergraduate" className="form-label-academic">
                      Undergraduate
                    </Label>
                    <Input
                      id="undergraduate"
                      type="number"
                      step="0.1"
                      value={settings.pricing.undergraduateMultiplier}
                      onChange={(e) =>
                        setSettings({
                          ...settings,
                          pricing: { ...settings.pricing, undergraduateMultiplier: Number(e.target.value) },
                        })
                      }
                      className="form-input-academic"
                    />
                  </div>
                  <div>
                    <Label htmlFor="masters" className="form-label-academic">
                      Master's
                    </Label>
                    <Input
                      id="masters"
                      type="number"
                      step="0.1"
                      value={settings.pricing.mastersMultiplier}
                      onChange={(e) =>
                        setSettings({
                          ...settings,
                          pricing: { ...settings.pricing, mastersMultiplier: Number(e.target.value) },
                        })
                      }
                      className="form-input-academic"
                    />
                  </div>
                  <div>
                    <Label htmlFor="phd" className="form-label-academic">
                      PhD
                    </Label>
                    <Input
                      id="phd"
                      type="number"
                      step="0.1"
                      value={settings.pricing.phdMultiplier}
                      onChange={(e) =>
                        setSettings({
                          ...settings,
                          pricing: { ...settings.pricing, phdMultiplier: Number(e.target.value) },
                        })
                      }
                      className="form-input-academic"
                    />
                  </div>
                </div>
              </div>
            </div>

            {/* Platform Settings */}
            <div className="settings-academic">
              <div className="settings-header-academic">
                <h3 className="heading-tertiary-academic">Platform Settings</h3>
                <p className="body-regular text-gray-700">Configure general platform settings and policies</p>
              </div>
              <div className="settings-grid-academic">
                <div>
                  <Label htmlFor="siteName" className="form-label-academic">
                    Site Name
                  </Label>
                  <Input
                    id="siteName"
                    value={settings.general.siteName}
                    onChange={(e) =>
                      setSettings({
                        ...settings,
                        general: { ...settings.general, siteName: e.target.value },
                      })
                    }
                    className="form-input-academic"
                  />
                </div>
                <div>
                  <Label htmlFor="supportEmail" className="form-label-academic">
                    Support Email
                  </Label>
                  <Input
                    id="supportEmail"
                    type="email"
                    value={settings.general.supportEmail}
                    onChange={(e) =>
                      setSettings({
                        ...settings,
                        general: { ...settings.general, supportEmail: e.target.value },
                      })
                    }
                    className="form-input-academic"
                  />
                </div>
                <div>
                  <Label htmlFor="minWithdrawal" className="form-label-academic">
                    Minimum Withdrawal ($)
                  </Label>
                  <Input
                    id="minWithdrawal"
                    type="number"
                    value={settings.platform.minimumWithdrawal}
                    onChange={(e) =>
                      setSettings({
                        ...settings,
                        platform: { ...settings.platform, minimumWithdrawal: Number(e.target.value) },
                      })
                    }
                    className="form-input-academic"
                  />
                </div>
                <div>
                  <Label htmlFor="maxFileSize" className="form-label-academic">
                    Max File Size (MB)
                  </Label>
                  <Input
                    id="maxFileSize"
                    type="number"
                    value={settings.general.maxFileSize}
                    onChange={(e) =>
                      setSettings({
                        ...settings,
                        general: { ...settings.general, maxFileSize: Number(e.target.value) },
                      })
                    }
                    className="form-input-academic"
                  />
                </div>
              </div>

              {/* Platform Controls */}
              <div className="mt-6">
                <h4 className="text-lg font-semibold mb-4 text-navy-900">Platform Controls</h4>
                <div className="space-y-4">
                  <div className="flex items-center justify-between">
                    <div>
                      <Label className="form-label-academic">Auto-approve Writers</Label>
                      <p className="text-sm text-gray-600">Automatically approve qualified writer applications</p>
                    </div>
                    <Checkbox
                      checked={settings.platform.autoApproveWriters}
                      onCheckedChange={(checked) =>
                        setSettings({
                          ...settings,
                          platform: { ...settings.platform, autoApproveWriters: checked as boolean },
                        })
                      }
                    />
                  </div>

                  <div className="flex items-center justify-between">
                    <div>
                      <Label className="form-label-academic">Maintenance Mode</Label>
                      <p className="text-sm text-gray-600">Put the platform in maintenance mode</p>
                    </div>
                    <Checkbox
                      checked={settings.general.maintenanceMode}
                      onCheckedChange={(checked) =>
                        setSettings({
                          ...settings,
                          general: { ...settings.general, maintenanceMode: checked as boolean },
                        })
                      }
                    />
                  </div>

                  <div className="flex items-center justify-between">
                    <div>
                      <Label className="form-label-academic">Registration Open</Label>
                      <p className="text-sm text-gray-600">Allow new user registrations</p>
                    </div>
                    <Checkbox
                      checked={settings.general.registrationOpen}
                      onCheckedChange={(checked) =>
                        setSettings({
                          ...settings,
                          general: { ...settings.general, registrationOpen: checked as boolean },
                        })
                      }
                    />
                  </div>
                </div>
              </div>
            </div>

            {/* Notification Settings */}
            <div className="settings-academic">
              <div className="settings-header-academic">
                <h3 className="heading-tertiary-academic">Notification Settings</h3>
                <p className="body-regular text-gray-700">Configure system notifications and alerts</p>
              </div>
              <div className="space-y-4">
                <div className="flex items-center justify-between">
                  <div>
                    <Label className="form-label-academic">Email Notifications</Label>
                    <p className="text-sm text-gray-600">Send email notifications for important events</p>
                  </div>
                  <Checkbox
                    checked={settings.notifications.emailNotifications}
                    onCheckedChange={(checked) =>
                      setSettings({
                        ...settings,
                        notifications: { ...settings.notifications, emailNotifications: checked as boolean },
                      })
                    }
                  />
                </div>

                <div className="flex items-center justify-between">
                  <div>
                    <Label className="form-label-academic">Order Updates</Label>
                    <p className="text-sm text-gray-600">Notify users about order status changes</p>
                  </div>
                  <Checkbox
                    checked={settings.notifications.orderUpdates}
                    onCheckedChange={(checked) =>
                      setSettings({
                        ...settings,
                        notifications: { ...settings.notifications, orderUpdates: checked as boolean },
                      })
                    }
                  />
                </div>

                <div className="flex items-center justify-between">
                  <div>
                    <Label className="form-label-academic">Payment Alerts</Label>
                    <p className="text-sm text-gray-600">Send alerts for payment-related events</p>
                  </div>
                  <Checkbox
                    checked={settings.notifications.paymentAlerts}
                    onCheckedChange={(checked) =>
                      setSettings({
                        ...settings,
                        notifications: { ...settings.notifications, paymentAlerts: checked as boolean },
                      })
                    }
                  />
                </div>
              </div>
            </div>

            {/* Save Button */}
            <div className="flex justify-end">
              <Button onClick={handleSaveSettings} className="btn-primary">
                <Save className="h-4 w-4 mr-2" />
                Save All Settings
              </Button>
            </div>
          </TabsContent>
        </Tabs>
      </div>
    </div>
  )
}
